%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% LaTeX PIQ class, Inria 2024
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{piq}[2024/05/21 PIQ LaTeX class]


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% General 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\newcommand{\piqdraft}{0}

% piq-interne/gabarits/latex/documents
\newcommand{\inrialogomarianne}{RF-Inria_Bloc-marque.png}
\newcommand{\inrialogoFR}{France2030_bleu-rouge.png}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\RequirePackage{xcolor}

\definecolor{inria-2024-rouge}      {HTML}{C9191E}
\definecolor{inria-2024-framboise}  {HTML}{A60F79}
\definecolor{inria-2024-violet}     {HTML}{5D4B9A}
\definecolor{inria-2024-bleu-nuit}  {HTML}{27348B}
\definecolor{inria-2024-bleu-canard}{HTML}{1067A3}
\definecolor{inria-2024-bleu-azur}  {HTML}{00A5CC}
\definecolor{inria-2024-bleu-vert}  {HTML}{88CCAA}
\definecolor{inria-2024-gris-bleu}  {HTML}{384257}
\definecolor{inria-2024-cactus}     {HTML}{608B37}
\definecolor{inria-2024-vert-tendre}{HTML}{95C11F}
\definecolor{inria-2024-jaune}      {HTML}{FFCD1C}
\definecolor{inria-2024-orange}     {HTML}{DD8300}
\definecolor{inria-2024-sable}      {HTML}{E2D0AA}

\definecolor{inria-noir}            {HTML}{000000}
\definecolor{inria-blanc}           {HTML}{FFFFFF}
\colorlet{inria-rouge}              {inria-2024-rouge}

\colorlet{inria-debug}              {inria-2024-sable}
\colorlet{inria-debug1}             {inria-2024-cactus}
\colorlet{inria-debug2}             {inria-2024-jaune}
\colorlet{inria-debug-bordure}      {inria-2024-jaune!20}
\colorlet{inria-debug-canvas}       {inria-2024-jaune!40}
\colorlet{inria-debug-interne}      {inria-2024-jaune!60}

\DeclareOption*{\PassOptionsToClass{\CurrentOption}{article}}
\ProcessOptions\relax
\LoadClass[11pt]{article}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\RequirePackage{ifdraft}
\RequirePackage{iftex}
\RequirePackage{tikz}
\RequirePackage{tikzpagenodes}
\RequirePackage{fmtcount}
\RequirePackage{calc}
\RequirePackage[colorlinks=true,pdfborder={0 0 0}]{hyperref}
\RequirePackage[a4paper]{geometry}
\RequirePackage{fullpage}
\RequirePackage{titling}
\RequirePackage{lastpage}
\RequirePackage{fancyhdr}
\RequirePackage[french]{babel}
\RequirePackage[document]{ragged2e}         % left justify
\RequirePackage{enumitem}
\RequirePackage{piq/inriafontes}
\RequirePackage[skip=8pt plus1pt, indent=40pt]{parskip}
\RequirePackage{amssymb}

\author{Programme Inria Quadrant}
\date{juillet 2024}

\newcommand{\piqtitle}{}
\renewcommand{\piqtitle}{\@title{}}

\newcommand{\switchtosans}{\switchtoinriasans}
\newcommand{\switchtoserif}{\switchtoinriaserif}
\newcommand{\switchtofont}{\switchtosans}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Head/Foot
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\pgfdeclareimage[height=2cm]{LogoMarianne}{\inrialogomarianne}
\pgfdeclareimage[height=2cm]{LogoFR}{\inrialogoFR}

\newcommand{\headerpicL}[1]{%
  \begin{tikzpicture}[remember picture,overlay]
    \node [anchor=north west,inner sep=0] at (current page header area.north west) 
    {\includegraphics[height=2cm]{#1}};
  \end{tikzpicture}
}

\newcommand{\headerpicR}[1]{%
  \begin{tikzpicture}[remember picture,overlay]
    \node [anchor=north east,inner sep=0] at (current page header area.north east) 
    {\includegraphics[height=2cm]{#1}};
  \end{tikzpicture}
}

%% RESET

\fancyhead{}
\fancyfoot{}
\renewcommand{\headrulewidth}{0pt}
\renewcommand{\footrulewidth}{0pt}

% \renewcommand\headrule{%
%   \begin{minipage}{1\textwidth}%
%      \hrule width \hsize height 1pt \kern 1mm %
%   \end{minipage}\par%
% }

\renewcommand\footrule{%
   \begin{minipage}{1\textwidth}%
       \hrule width \hsize height 1pt \kern 1mm %
   \end{minipage}\par%
}

%% SET

\setlength{\headheight}{14.5pt}

\fancyfoot[L]{\switchtofont\piqtitle{} - \@date{} - \href{https://piq.inria.fr/}{\url{https://piq.inria.fr}}}
\fancyfoot[C]{}
\fancyfoot[R]{\switchtofont\thepage/\pageref{LastPage}}


%% \maketitle defines the `plain` page style
%% \let\ps@plain\ps@fancy

\fancypagestyle{plain}{%
\fancyhead[L]{\headerpicL{\inrialogomarianne}}
\fancyhead[R]{\headerpicR{\inrialogoFR}}
}


%% normal pages
\pagestyle{fancy}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Section / Subsection
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\renewcommand{\section}{%
     \@startsection
     {section}{1}{0pt}%              % mise en place dans la toc
     {-3ex plus -1ex minus -.2ex}%   % saut supérieur + glue
     {2ex plus .2ex}%                % saut inférieur + glue
     {\bf\switchtofont}%
}

\renewcommand{\subsection}{%
     \@startsection
     {subsection}{2}{0pt}%
     {-2.5ex plus -1ex minus -.2ex}%
     {1.5ex plus .2ex}%
     {\bf\switchtofont}%
}

\setcounter{secnumdepth}{0}
\renewcommand{\arraystretch}{1.5}
\setlength\parindent{0pt}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Maketitle
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% 


\def\@maketitle{%
  \newpage
  \vspace*{3cm} %-\topskip}      % remove the initial space
  \begingroup\centering    % instead of \begin{center}
  \let \footnote \thanks
  \hrule height \z@        % to avoid the insertion of lineskip glue
    {\huge \textbf{\@title} \par}%
    \vskip 1.5em 
    {\large \@author \par}%
    \vskip 1em
    % {\large \@date}%
  \par\endgroup            % instead of \end{center}
  \vspace*{2em}             % <--- modify this to adjust the separation
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Delayed excution
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\AtBeginDocument{%
  \switchtofont

\renewcommand{\labelitemi}{$\bullet$}
\renewcommand{\labelitemii}{$\circ$}
\renewcommand{\labelitemiii}{$\circ$}
\renewcommand{\labelitemiv}{$\circ$}
\setlist{leftmargin=5.5mm}

%%  frenchle module
% \frlabelitems{%
% \renewcommand{\labelitemi}{$\bullet$}%
% \renewcommand{\labelitemii}{**}%
% \renewcommand{\labelitemiii}{***}%
% \renewcommand{\labelitemiii}{****}%
% }%
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
